Crossbar.io
===========

`Crossbar.io <http://crossbar.io>`__ is a networking platform for distributed
and microservice applications.

It is feature rich, scalable, robust and secure. Let Crossbar.io take care of
the hard parts of messaging so you can focus on your app's features.

| |Version| |Downloads| |Build Status| |Coverage|

Resources
---------

-  Read more on the `Project Homepage <http://crossbar.io>`__
-  Jump into the `Quick Start <http://crossbar.io/docs/Quick-Start/>`__
-  Checkout the complete `Documentation <http://crossbar.io/docs/>`__
-  Join the `Mailing List <https://groups.google.com/forum/#!forum/crossbario>`__
-  Follow us on `Twitter <https://twitter.com/crossbario>`__
-  Ask a question on `StackOverflow <http://stackoverflow.com/questions/ask?tags=crossbar,wamp>`__
-  Read our `Legal Notes <https://github.com/crossbario/crossbar/blob/master/legal/README.md>`__

.. |Version| image:: https://img.shields.io/pypi/v/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar
.. |Downloads| image:: https://img.shields.io/pypi/dm/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar
.. |Build Status| image:: https://travis-ci.org/crossbario/crossbar.svg?branch=master
   :target: https://travis-ci.org/crossbario/crossbar
.. |Coverage| image:: https://img.shields.io/codecov/c/github/crossbario/crossbar/master.svg
   :target: https://codecov.io/github/crossbario/crossbar
